{% extends "admin/change_list.html" %}

{% load admin_list dblog_admin %}

{% block extrastyle %}
	{{ block.super }}
	<style type="text/css">
		#changelist .start-cell td,
		#changelist .start-cell th {
			border-bottom: 0 !important;
		}
		#changelist .meta-info {
			color:#666;
		}
		#changelist td,
		#changelist th {
			padding-bottom: 3px;
			border-left: 0 !important;
			border: 0 !important;
		}
		#changelist .end-cell td {
			border-top: 0;
			padding-top: 2px;
		}
		#changelist td { border-color: inherit !important; }
		#changelist .cell-status-1 {
			background: inherit !important;
			border-color: inherit !important;
			color: #666;
			text-decoration: line-through;;
		}
		#changelist .cell-status-0,
		#changelist .cell-level-40,
		#changelist .cell-level-50 {
			background: #FDC;
			border-color: #E88;
		}
		#changelist .cell-status-0.row2,
		#changelist .cell-level-40.row2,
		#changelist .cell-level-50.row2 {
			background: #FED;
			border-color: #E99;
		}
		#changelist .cell-level-30 {
			background: #ffb;
			border-color: #eea;
		}
		#changelist .cell-level-30.row2 {
			background: #ffd;
			border-color: #dd8;
		}

		#changelist .cell-level-20 {
			background: #DDFFFF;
			border-color: #BBEEEE;
		}
		#changelist .cell-level-20.row2 {
			background: #E7FFFF;
			border-color: #CCEEEE;
		}
		
		#changelist .cell-level-10 {
			background: #DDE7FF;
			border-color: #CCDDEE;
		}
		#changelist .cell-level-10.row2 {
			background: #E7EEFF;
			border-color: #CCDDEE;
		}
	</style>
{% endblock %}

{% block result_list %}
    {% if action_form and actions_on_top %}{% admin_actions %}{% endif %}
	{% result_list cl %}
    {% if action_form and actions_on_bottom %}{% admin_actions %}{% endif %}
{% endblock %}