{% extends "admin/change_form.html" %}

{% load i18n admin_modify adminmedia %}

{% block extrahead %}
	{{ block.super }}
	{% if has_traceback %}
		{{ error_headers }}
		<style type="text/css">
		#reporter_body { 
			padding: 8px;
			background: none repeat scroll 0 0 #FFFFCC
		}
		#reporter_body #traceback li { list-style-type: inherit; }
		#reporter_body #traceback { padding: 8px; margin-top: 10px; }
		#reporter_body td, #reporter_body th { border-bottom: 0; font:small sans-serif; line-height: auto; }
		#content { margin: 0; }
		</style>
	{% endif %}
	<style type="text/css">
	#meta { border-top: 0; }
	#meta th, #meta td { border: 0; padding: 8px; }
	#meta th { text-align: left; }
	</style>
{% endblock %}

{% block content_title %}{% endblock %}

{% block content %}
	{% if not has_traceback %}
		{{ block.super }}
	{% else %}
		<table id="meta">
			<colgroup>
				<col style="width:15%"/>
				<col style="width:35%"/>
				<col style="width:15%"/>
				<col style="width:35%"/>
			</colgroup>

			<tr>
				<th>URL:</th>
				<td><a href="{{ instance.url }}">{{ instance.url }}</a></td>
				<th>Level:</th>
				<td>{{ instance.get_level_display }}</td>
			</tr>
			<tr>
				<th>Server:</th>
				<td>{{ instance.server_name }}</td>
				<th>Date:</th>
				<td>{{ instance.datetime }}</td>
			</tr>
		</table>
		<p><a href="?raw">View raw (standard) traceback information instead.</a></p>
		<div id="reporter_body">
			{{ error_body }}
		</div>
	{% endif %}
{% endblock %}